pub struct Poly<V, const MAX_VOICES: usize = 32> { /* private fields */ }Expand description
A helper struct for implementing polyphonic synths.
This struct handles common tasks such as routing events to voices, updating note expression curves, and mixing the output of voices.
To use it, you must implement the Voice trait for your synth. Then, use the methods
on this struct to implement the required [conformal_component::synth::Synth] trait methods.
Implementations
Sourceimpl<V: Voice, const MAX_VOICES: usize> Poly<V, MAX_VOICES>
impl<V: Voice, const MAX_VOICES: usize> Poly<V, MAX_VOICES>
Sourcepub fn handle_events(&mut self, context: &impl HandleEventsContext)
pub fn handle_events(&mut self, context: &impl HandleEventsContext)
Handles a set of events without rendering audio.
This can be used to implement [conformal_component::synth::Synth::handle_events].
Sourcepub fn process(
&mut self,
context: &impl ProcessContext,
shared_data: &V::SharedData<'_>,
output: &mut impl BufferMut,
)
pub fn process( &mut self, context: &impl ProcessContext, shared_data: &V::SharedData<'_>, output: &mut impl BufferMut, )
Renders the audio for the synth.
This can be used to implement [conformal_component::synth::Synth::process].
For any voices with active notes, Voice::process will be called.